# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add 'Awaiting QA' to 'Complete' transition for standard calibration

Revision ID: 2e185d05a21f
Revises: 25db7ee329f4
Create Date: 2021-10-27 07:22:47.394930

"""
from alembic import op

# revision identifiers, used by Alembic.
revision = "2e185d05a21f"
down_revision = "25db7ee329f4"
branch_labels = None
depends_on = None


def upgrade():
    """
    Add the Awaiting QA => Complete transition
    to capability_state_transitions table

    :return:
    """
    op.execute(
        """
INSERT INTO capability_state_transitions
    (capability_name, from_state, to_state, pattern)
    VALUES ('std_calibration', 'Awaiting QA', 'Complete',
            'type == qa-pass')
    """
    )


def downgrade():
    """
    Remove the Awaiting QA => Complete transition
    from capability_state_transitions table

    :return:
    """
    op.execute(
        """
    DELETE FROM capability_state_transitions
    WHERE capability_name='std_calibration'
    AND from_state='Awaiting QA'
    AND to_state='Complete'
    AND pattern='type == qa-pass'
    """
    )
